@@ -70,7 +70,7 @@ __attribute__ ((constructor)) void init()
 	
 	SettingsItem si;
 	
-	si.icon = QIcon(":/opensubtitles/opensubtitles.png");
+	si.icon = DelayedIcon(":/opensubtitles/opensubtitles.png");
 	si.title = QObject::tr("Subtitles search");
 	si.lpfnCreate = SettingsSubtitles::create;
 	
@@ -81,7 +81,7 @@ extern "C" __attribute__((visibility("default"))) PluginInfo getInfo()
 {
 	PluginInfo info;
 	
-	info.version = "1.1.2";
+	info.version = "1.1.3";
 	info.name = QObject::tr("OpenSubtitles.org search");
 	info.author = QString::fromUtf8("Luboš Doležel");
 	info.website = "http://fatrat.dolezel.info";
